using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Advent.MxRules.Resources;

namespace Advent.MxRules.Win.Controls
{
    public partial class MxrTreeNode : UserControl
    {
        public MxrTreeNode()
        {
            InitializeComponent();
            this.SetImage();
        }

        #region Properties

        private bool m_isExpanded = false;

        [Browsable(true), Description("Gets whether the node is expanded.")]
        public bool IsExpanded
        {
            get
            {
                return this.m_isExpanded;
            }
        }

        private void SetIsExpanded(bool isExpanded)
        {
            m_isExpanded = isExpanded;
        }

        [Browsable(true), Description("Gets or sets the node text displayed.")]
        public string NodeText
        {
            get
            {
                return this.lblNodeName.Text;
            }
            set
            {
                this.lblNodeName.Text = value;
            }

        }


        #endregion

        #region Events

        void pbExpandCollapse_Click(object sender, System.EventArgs e)
        {
            this.ToggleNode();
            MxrTreeNodeEventArgs e2 = new MxrTreeNodeEventArgs(this.IsExpanded);
            OnNodeToggled(e2);
        }

        public event MxrTreeNodeEventHandler NodeToggled;

        protected virtual void OnNodeToggled(MxrTreeNodeEventArgs e)
        {
            if (NodeToggled != null)
            {
                NodeToggled(this, e);
            }


        }
        public delegate void MxrTreeNodeEventHandler(object sender, MxrTreeNodeEventArgs e);

        public class MxrTreeNodeEventArgs : EventArgs
        {
            bool m_bExpanded = false;

            public MxrTreeNodeEventArgs(bool isExpanded)
            {
                m_bExpanded = isExpanded;
            }

            public bool NodeIsExpanded
            {
                get
                {
                    return m_bExpanded;
                }

            }

        }

        #endregion

        #region UI Setting

        private void ToggleNode()
        {
            this.SetIsExpanded(!this.IsExpanded);
            this.SetImage();

        }

        private void SetImage()
        {
            if (this.IsExpanded)
            {

                this.pbExpandCollapse.Image = ResourceManager.GetImage( ResourceManager.MxrImages.Expanded );
            }
            else
            {
                this.pbExpandCollapse.Image = ResourceManager.GetImage( ResourceManager.MxrImages.Collapsed );
            }

        }

        #endregion

        

    }
}
